FieldInfo class

Represents a field of a typedef

Constructors

FieldInfo({required String name, required String type, required bool isNullable, required bool isList, required bool isCustomType, bool isEnum = false, String? jsonKey, String? defaultValue})

Properties

defaultValue String?
final
hashCode int
The hash code for this object.
no setterinherited
isCustomType bool
final
isEnum bool
final
isList bool
final
isNullable bool
final
jsonKey String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited