ModelParser class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseAllModels(
String content) → List< TypedefInfo> - Parses all models (typedefs + classes) from a file
-
parseClasses(
String content) → List< TypedefInfo> - Parses classes from a file
-
parseEnums(
String content) → List< String> - Parses enums from a file
-
parseEnumsWithValues(
String content) → Map< String, String> - Parses enums with their values
-
parseTypedefs(
String content) → List< TypedefInfo> - Parses typedefs from a file
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited